==> pegasus-merchandise-api-2.1.5-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSupplierCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;


/**
 * @author Eric.Lou
 * @version $Id: ScmSupplierCond.java, v 0.1 2015-07-28 17:21
 */
public class PcsSupplierCond extends BaseQueryCond implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 8678207173401990591L;

	private String name;

    private String nameCn;

    private Integer supplierStatus;
    
    private Integer supplierOrderStatus;

    private Integer type;
    
    private String operatorName;
    
    private Long categoryManager;//品类经理
    
    private Integer userId;
    
    private Integer roleId;
    
    
    private Integer[] statusArr;
    
    private String sortField = "t1.ID";
    
    private String sortType = "desc";
    
    private Long createUserId;
    
    

	public Long getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	public String getSortField() {
		return sortField;
	}

	public void setSortField(String sortField) {
		this.sortField = sortField;
	}

	public String getSortType() {
		return sortType;
	}

	public void setSortType(String sortType) {
		this.sortType = sortType;
	}

	public Integer[] getStatusArr() {
		return statusArr;
	}

	public void setStatusArr(Integer[] statusArr) {
		this.statusArr = statusArr;
	}

	public Integer getUserId() {
		return userId;
	}

	public void setUserId(Integer userId) {
		this.userId = userId;
	}

	public Integer getRoleId() {
		return roleId;
	}

	public void setRoleId(Integer roleId) {
		this.roleId = roleId;
	}

	public Long getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Long categoryManager) {
		this.categoryManager = categoryManager;
	}

    
    public String getOperatorName() {
		return operatorName;
	}

	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public Integer getSupplierOrderStatus() {
		return supplierOrderStatus;
	}

	public void setSupplierOrderStatus(Integer supplierOrderStatus) {
		this.supplierOrderStatus = supplierOrderStatus;
	}

	//mehtod
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public Integer getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(Integer supplierStatus) {
        this.supplierStatus = supplierStatus;
    }

    //constructor
    public PcsSupplierCond() {
        super();
    }

}

==> pegasus-merchandise-api-2.2.24-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSupplierCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import java.io.Serializable;
import java.util.List;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;


/**
 * @author Eric.Lou
 * @version $Id: ScmSupplierCond.java, v 0.1 2015-07-28 17:21
 */
public class PcsSupplierCond extends BaseQueryCond implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 8678207173401990591L;

	private String name;

    private String nameCn;

    private Integer supplierStatus;
    
    private Integer supplierOrderStatus;

	private List<Integer> supplierOrderStatusList;
    private Integer type;
    
    private String operatorName;
    
    private Long categoryManager;//品类经理
    
    private Integer userId;
    
    private Integer roleId;

	private Long submitAuditUserId;
    
    private Integer[] statusArr;
    
    private String sortField = "t1.ID";
    
    private String sortType = "desc";
    
    private Long createUserId;

    private boolean havePermission;		// 是否查询供应商权限
    
    private List<Long> idList;		// 供应商id集合
    //是否OEM查询
    private boolean oemQuery;

	public Long getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	public String getSortField() {
		return sortField;
	}

	public void setSortField(String sortField) {
		this.sortField = sortField;
	}

	public String getSortType() {
		return sortType;
	}

	public void setSortType(String sortType) {
		this.sortType = sortType;
	}

	public Integer[] getStatusArr() {
		return statusArr;
	}

	public void setStatusArr(Integer[] statusArr) {
		this.statusArr = statusArr;
	}

	public Integer getUserId() {
		return userId;
	}

	public void setUserId(Integer userId) {
		this.userId = userId;
	}

	public Integer getRoleId() {
		return roleId;
	}

	public void setRoleId(Integer roleId) {
		this.roleId = roleId;
	}

	public Long getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Long categoryManager) {
		this.categoryManager = categoryManager;
	}

    
    public String getOperatorName() {
		return operatorName;
	}

	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public List<Integer> getSupplierOrderStatusList() {
		return supplierOrderStatusList;
	}

	public void setSupplierOrderStatusList(List<Integer> supplierOrderStatusList) {
		this.supplierOrderStatusList = supplierOrderStatusList;
	}

	public Long getSubmitAuditUserId() {
		return submitAuditUserId;
	}

	public void setSubmitAuditUserId(Long submitAuditUserId) {
		this.submitAuditUserId = submitAuditUserId;
	}

	public Integer getSupplierOrderStatus() {
		return supplierOrderStatus;
	}

	public void setSupplierOrderStatus(Integer supplierOrderStatus) {
		this.supplierOrderStatus = supplierOrderStatus;
	}

	//mehtod
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameCn() {
        return nameCn;
    }

    public void setNameCn(String nameCn) {
        this.nameCn = nameCn;
    }

    public Integer getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(Integer supplierStatus) {
        this.supplierStatus = supplierStatus;
    }

    public boolean isHavePermission() {
		return havePermission;
	}
	public void setHavePermission(boolean havePermission) {
		this.havePermission = havePermission;
	}

	public List<Long> getIdList() {
		return idList;
	}

	public void setIdList(List<Long> idList) {
		this.idList = idList;
	}

	public boolean isOemQuery() {
		return oemQuery;
	}

	public void setOemQuery(boolean oemQuery) {
		this.oemQuery = oemQuery;
	}

	//constructor
    public PcsSupplierCond() {
        super();
    }
}
